@@ -47,7 +47,7 @@
 #include "common.h"
 #include "wpa.h"
 
-#define WLANCOND_SHUTDOWN_DELAY 60000 //60s
+#define WLANCOND_SHUTDOWN_DELAY 4000 //4s
 #define WLANCOND_CONNECT_TIMEOUT 10000 //10s
 
 /* Interface name cache */
@@ -476,6 +476,7 @@ static gboolean wlan_if_down_cb(void* data)
 void set_wlan_state(int new_state, int send_signal, force_t force) 
 {
         int sock;
+        guint shutdown_delay = WLANCOND_SHUTDOWN_DELAY;
 
 #ifdef DEBUG
         static char *status_table[] = 
@@ -492,16 +493,24 @@ void set_wlan_state(int new_state, int send_signal, force_t force)
 
                 set_scan_state(SCAN_NOT_ACTIVE);
                 
-                clear_wpa_mode();
+                if (get_wlan_state() != WLAN_NOT_INITIALIZED)
+                        clear_wpa_mode();
+                
                 clean_ssid();
 
                 wlan_status.mode = 0;
 
                 /* Remove association timer */
                 remove_connect_timer();
+
+                /* Check the shutdown delay */
+                if (get_mic_status()) {
+                        shutdown_delay = MIC_FAILURE_TIMEOUT;
+                }
                 
                 if (force == FORCE_MAYBE) {
                         if (get_mic_status()) {
+                                // MIC failure going on
                                 force = FORCE_NO;
                         } else {
                                 force = FORCE_YES;
@@ -539,7 +548,7 @@ void set_wlan_state(int new_state, int send_signal, force_t force)
                         }
                         
                         wlan_if_down_timer_id = g_timeout_add(
-                                WLANCOND_SHUTDOWN_DELAY,
+                                shutdown_delay,
                                 wlan_if_down_cb,
                                 NULL); 
                         
@@ -1283,8 +1292,8 @@ static DBusHandlerResult scan_request(DBusMessage    *message,
         
         init_iwreq(&req);
         req.u.essid.pointer = (caddr_t)ssid;
-        req.u.essid.length = ssid_len;
-         
+        req.u.essid.flags = IW_SCAN_THIS_ESSID;
+
         if (ssid_len > WLANCOND_MAX_SSID_SIZE + 1) {
                 DLOG_DEBUG("Invalid SSID\n");
                 goto param_err;
@@ -1292,14 +1301,11 @@ static DBusHandlerResult scan_request(DBusMessage    *message,
         
         if (ssid != NULL && ssid_len > 1) {
                 DLOG_DEBUG("Found ssid '%s' for active scan", ssid);
-                req.u.essid.flags = IW_SCAN_THIS_ESSID; 
+                req.u.essid.length = ssid_len;
                 
                 if (scan_ssid != NULL)
                         g_free(scan_ssid);
                 scan_ssid = g_strdup(ssid);
-        } else {
-                DLOG_DEBUG("Passive scan");
-                req.u.essid.flags = IW_SCAN_ALL_ESSID;
         }
         
 #ifdef NORMAL_SCAN
@@ -1387,7 +1393,7 @@ static int network_compare(gconstpointer a, gconstpointer b)
      Scan results request.
      @return status. 
 */
-int ask_scan_results(void) 
+int ask_scan_results(int ifindex) 
 {
         struct iwreq req;
         char *buffer = NULL;
@@ -1448,23 +1454,21 @@ int ask_scan_results(void)
         {
                 struct iw_event            iwe;
                 struct stream_descr        stream;
-                int                        ret;
-                int                        has_range;
-                struct iw_range            range;
                 struct scan_results_t      *scan_results;
-                gboolean wap_handled = FALSE;
+                struct wireless_iface      *wireless_if;
+                int                        ret;
+                gboolean                   wap_handled = FALSE;
 
                 scan_results = g_new0(struct scan_results_t, 1);
                 memset(&iwe, 0, sizeof(iwe));
-
-                has_range = (iw_get_range_info(sock, ifname, &range) >= 0);
+                
+                wireless_if = get_interface_data(ifindex);
 
                 iw_init_event_stream(&stream, buffer, req.u.data.length);
                 do
                 {
                         /* Extract an event */
-                        ret = iw_extract_event_stream(&stream, &iwe,
-                                                      range.we_version_compiled);
+                        ret = iw_extract_event_stream(&stream, &iwe, wireless_if->range.we_version_compiled);
                         if (ret > 0) {
                                 /* Let's peek what is coming so that we can
                                    separate different access points from
@@ -1481,9 +1485,7 @@ int ask_scan_results(void)
                                                 wap_handled = TRUE;
                                         }
                                 }
-                                print_event_token(&iwe, &range,
-                                                  has_range,
-                                                  scan_results);
+                                print_event_token(&iwe, scan_results, ifindex);
 
                         }
 
@@ -1918,8 +1920,10 @@ static DBusHandlerResult set_powersave_request(DBusMessage    *message,
         }
         
         if (onoff == TRUE) {
-                // Go to power save if not acquiring address
-                if (get_wlan_state() != WLAN_NO_ADDRESS) {
+                if (get_wlan_state() == WLAN_NOT_INITIALIZED && !get_mic_status()) {
+                        set_wlan_state(WLAN_NOT_INITIALIZED, NO_SIGNAL, FORCE_YES);
+                } else if (get_wlan_state() != WLAN_NO_ADDRESS) {
+                        // Go to power save if not acquiring address
                         if (set_power_state(WLANCOND_SHORT_CAM, sock) == 
                             FALSE) {
                                 DLOG_ERR("Setting powersave failed");
