@@ -65,20 +65,6 @@ struct rtnl_handle
 	__u32			dump;
 };
 
-typedef struct wireless_iface
-{
-        /* Linked list */
-        struct wireless_iface *	next;
-        
-        /* Interface identification */
-        int ifindex; /* Interface index == black magic */
-        
-        /* Interface data */
-        char ifname[IFNAMSIZ + 1]; /* Interface name */
-        struct iw_range	range; /* Wireless static data */
-        int has_range;
-} wireless_iface;
-
 /* Local functions */
 static void handle_custom_event(char* event_pointer, int len, 
                                 struct scan_results_t *scan_results);
@@ -247,7 +233,7 @@ static void connected_signal(struct scan_results_t *scan_results,
                 send_and_unref(get_dbus_connection(), connected);
         }
 }
-        
+
 /**
    Handle WAP wireless event.
    @param event extracted token.
@@ -291,7 +277,7 @@ static void handle_wap_event(struct scan_results_t *scan_results,
                 if (state != WLAN_CONNECTED) {
                         set_wlan_state(WLAN_NO_ADDRESS, NO_SIGNAL, FORCE_NO);
                 }
-                
+
                 //set_wlan_state(WLAN_CONNECTED, NO_SIGNAL, FORCE_NO);
         } else {
                 
@@ -306,15 +292,12 @@ static void handle_wap_event(struct scan_results_t *scan_results,
 /**
    Print or save wireless events.
    @param event extracted token.
-   @param range range info.
-   @param has range Is range info valid.
    @param scan_results structure where scan results are saved.
    @return status.
  */
-int print_event_token(struct iw_event *event,	/* Extracted token */
-                      struct iw_range *range,	/* Range info */
-                      int has_range,
-                      struct scan_results_t *scan_results)
+int print_event_token(struct iw_event *event, 
+                      struct scan_results_t *scan_results,
+                      int ifindex)
 {
 
         /* Now, let's decode the event */
@@ -437,7 +420,7 @@ int print_event_token(struct iw_event *event,	/* Extracted token */
             {
                     if (get_scan_state() == SCAN_ACTIVE) {
                             DLOG_DEBUG("Scan results ready -- scan active");
-                            if (ask_scan_results() == FALSE) {
+                            if (ask_scan_results(ifindex) == FALSE) {
                                     DLOG_ERR("Getting scan results failed");
                             }
 #ifdef DEBUG
@@ -692,7 +675,7 @@ static inline int index2name(int skfd, int ifindex, char *name)
    @param ifindex Interface index.
    @return wireless_iface The wireless interface.
  */
-struct wireless_iface *iw_get_interface_data(int ifindex)
+struct wireless_iface *get_interface_data(int ifindex)
 {
         struct wireless_iface *	curr;
         int skfd = -1;	/* ioctl socket */
@@ -754,11 +737,10 @@ static int print_event_stream(int ifindex, char *data, int len)
         struct iw_event	iwe;
         struct stream_descr stream;
         int ret;
-        struct iw_range	range;
         struct wireless_iface *wireless_if;
         struct scan_results_t scan_results;
         
-        wireless_if = iw_get_interface_data(ifindex);
+        wireless_if = get_interface_data(ifindex);
 
         if (wireless_if == NULL)
                 return (-1);        
@@ -775,7 +757,7 @@ static int print_event_stream(int ifindex, char *data, int len)
                 if (ret != 0)
                 {
                         if (ret > 0)
-                                print_event_token(&iwe, &range, wireless_if->has_range, &scan_results);
+                                print_event_token(&iwe, &scan_results, ifindex);
                         else
                                 die("Invalid event");
                 }
